<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Edumarket tinymce Plugin search result popup.
 *
 * @package tinymce_edumarket
 * @author Lilian
 * @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 * @copyright KIPT Technology Corp. {@link http://kipt.com.tw/}
 */

require('../../../../../config.php');

$showpage = 6; // 一次顯示幾個分頁

$query = optional_param('q', '', PARAM_RAW);
$domain = optional_param('d', '', PARAM_RAW);
$grade = optional_param('g', '', PARAM_RAW);
$thispage = optional_param('page', '1', PARAM_RAW);

$PAGE->set_context(context_system::instance());
$PAGE->set_url('/lib/editor/tinymce/plugins/edumarket/searchresult.php');
$PAGE->set_pagelayout('popup');
$PAGE->set_title('查詢「'.$query.'」的結果');

$editor = get_texteditor('tinymce');
$plugin = $editor->get_plugin('edumarket');

$PAGE->requires->js('/lib/editor/tinymce/tiny_mce/' . $editor->version . '/tiny_mce_popup.js', true);
$PAGE->requires->js('/lib/editor/tinymce/plugins/edumarket/tinymce/js/edumarket.js', true);
$PAGE->requires->css('/lib/editor/tinymce/plugins/edumarket/tinymce/css/edumarket.css', true);

global $SESSION;
$SESSION->{'edumarket_tinymce_keyword'} = $query;
$SESSION->{'edumarket_tinymce_domain'} = $domain;
$SESSION->{'edumarket_tinymce_grade'} = $grade;

echo $OUTPUT->header();
?>
    <div class="panel_wrapper">
        <div id="general_panel" class="panel current">
<?php
    $url = get_config('tinymce_edumarket')->serverurl.'/api/resources.jsp?op=search&keyword='.$query.'&domain='.$domain.'&grade='.$grade.'&key='.get_config('tinymce_edumarket')->apikey.'&rows=5&page='.$thispage;
    
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_HEADER, 0);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
    curl_setopt($ch, CURLOPT_URL, $url);
    $html = curl_exec($ch);
    if (curl_error($ch)) {
        die(curl_error($ch));
    }
    $status = curl_getinfo($ch, CURLINFO_HTTP_CODE);

    if ($status === 200) {
        $xml = simplexml_load_string($html);
        foreach ($xml->resource as $element) {
            $domain = ''; $grade = ''; $keyword = '';
            
            $search_result = '<p style="font-weight:bold;color:#F00;">授權資訊：'.$element->copyright.'</p>';
            $search_result .= '<p>資源編號：'.$element->id.'</p>';
            $search_result .= '<p><img src="'.get_config('tinymce_edumarket')->serverurl.'/image/'.$element->id.'" width="90" height="90"></p>';
            $search_result .= '<p style="font-weight:bold;">標題：'.$element->title.'</p>';
            $search_result .= '<p>描述：'.$element->desc.'</p>';
            
            $search_result_complete = $search_result;
            $search_result_complete .= '<p>資源類型：'.$element->resourcetype.'</p>';
            
            $array = $element->domain;
            foreach ($array as $str) {
                $domain .= $str.'、';
            }
            $domain = mb_substr($domain, 0, -1, "utf-8");
            $search_result_complete .= '<p>適用領域議題：'.$domain.'</p>';
            
            $array = $element->grade;
            foreach ($array as $str) {
                $grade .= $str.'、';
            }
            $grade = mb_substr($grade, 0, -1, "utf-8"); 
            $search_result_complete .= '<p>適用年級：'.$grade.'</p>';
            
            $array = $element->keyword;
            foreach ($array as $str) {
                $keyword .= $str.'、';
            }
            $keyword = mb_substr($keyword, 0, -1, "utf-8");
            $search_result_complete .= '<p>關鍵字：'.$keyword.'</p>';

            $array = $element->contributor;
            foreach ($array as $subarray) {
                $search_result_complete .= '<p>'.$subarray->role.'：'.$subarray->name.'</p>';
            }
            
            $search_result_complete .= '<p>教學時數：'.$element->learntime.'</p>';
            $search_result_complete .= '<p>適用對象：'.$element->enduser.'</p>';
            $search_result_complete .= '<p>先備能力：'.$element->prerequisite.'</p>';
            $search_result_complete .= '<p>最後更新日期：'.$element->lastupdate.'</p>';
            
            $array = $element->attachment;
            foreach ($array as $subarray) {
                if ($subarray['type'] == 'file') {
                    $search_result .= '<p>檔案：<a href="'.$subarray->link.'" target="_blank">'.$subarray->name.'</a> ('.$subarray->size.')</p>';
                    $search_result_complete .= '<p>檔案：<a href="'.$subarray->link.'" target="_blank">'.$subarray->name.'</a> ('.$subarray->size.')</p>';
                } else {
                    $search_result .= '<p>連結：<a href="'.$subarray->link.'" target="_blank">'.$subarray->link.'</a> ('.$subarray->name.')</p>';
                    $search_result_complete .= '<p>連結：<a href="'.$subarray->link.'" target="_blank">'.$subarray->link.'</a> ('.$subarray->name.')</p>';
                }
            }
            
            // 將特殊符號轉成代碼，注意單雙引號
            $search_result = str_replace(array("\r", "\n", "\r\n", "\n\r"), '<br/>', $search_result);
            $search_result = str_replace("\"", '&quot;', $search_result);
            $search_result = str_replace("'", '&#39;', $search_result);
            $search_result_complete = str_replace(array("\r", "\n", "\r\n", "\n\r"), '<br/>', $search_result_complete);
            $search_result_complete = str_replace("\"", '&quot;', $search_result_complete);
            $search_result_complete = str_replace("'", '&#39;', $search_result_complete);
            
            $copyrightcode = '01';
            // copyright 處理
            if (isset($element->copyright['code'])) {
                $copyrightcode = $element->copyright['code'];
                if ($copyrightcode != '101' && $copyrightcode != '110') {
                    $copyrightcode = '<span class="copyright c'.substr($copyrightcode, -2).'"></span>';
                    $copyrightcode = '<span class="copyright cc"></span>'.$copyrightcode;
                } else {
                    $copyrightcode = '<span class="copyright c'.$copyrightcode.'"></span>';
                }
            }
?>
    <div class="loctable dash_bottom">
        <div class="fixed pr8"><img src="<?=get_config('tinymce_edumarket')->serverurl.'/image/'.$element->id?>" width="90" height="90"></div>
        <div class="changed loctable p-mb2">
            <h3><a href="<?=$element->url?>" target="_blank"><?=$element->title?></a><span class="btype <?=$element->bmtype?>"><?=$element->bmtype?></span><?=$copyrightcode?></h3>
            <p><script language="javascript">document.write(restr('<?=str_replace(array("\r", "\n", "\r\n", "\n\r"), '', $element->desc)?>', 200))</script></p>
            <p>適用領域議題：<?=$domain?>　　適用年級：<?=$grade?></p>
            <p class="icon_tag"><?=$keyword?></p>
            <div class="loctable width100">
                <div class="changed">點閱：<?=$element->click?>　　迴響：<?=$element->share?>　　下載：<?=$element->download?></div>
                <div class="fixed pr5 pb5">
                    <button class="btn" onclick="insertReaources('<?=nl2br($search_result)?>');return false;">插入資源(精簡)</button>
                    <button class="btn-primary btn" onclick="insertReaources('<?=nl2br($search_result_complete)?>');return false;">插入資源(完整)</button>
                    <?=$OUTPUT->help_icon('edumarket_btndetail', 'tinymce_edumarket', '')?>
                </div>
            </div>
        </div>
    </div>
<?php
        }
        $pagehtml = '';
        $totalpage = $xml->totalpage;
        if ($totalpage > 1) {
            $pagestart = 1;
            
            // 取得 list 初始頁
            if ($thispage > ($showpage/2)) {
                if ($thispage >= $totalpage - $showpage/2 + 1)
                    $pagestart = $totalpage - $showpage+1;
                else
                    $pagestart = $thispage - $showpage/2 + 1;
                if ($pagestart < 1)
                    $pagestart = 1;
            }
            
            if ($thispage != 1) {
                $pagehtml .= '<a href="#" onclick="reloadPage(window.location.href, 1)">第一頁</a>';
                $pagehtml .= '<a href="#" onclick="reloadPage(window.location.href, '.($thispage-1).')">上一頁</a>';
            }
            for ($i = $pagestart ; $i <= $pagestart+$showpage-1 && $i <= $totalpage ; $i++) {
                $pagehtml .= '<a href="#" '.($i == $thispage ? 'class="selected"' : '').' onclick="reloadPage(window.location.href, '.$i.')">'.$i.'</a>';
            }
            if ($thispage != $totalpage) {
                $pagehtml .= '<a href="#" onclick="reloadPage(window.location.href, '.($thispage+1).')">下一頁</a>';
                $pagehtml .= '<a href="#" onclick="reloadPage(window.location.href, '.$totalpage.')">最後一頁</a>';
            }
        }
?>
            <div class="pagelist"><?=$pagehtml?></div>
<?php
    } else {
        curl_close($ch);
    }
?>
        </div>
    </div>
<script>
if (document.getElementById('general_panel').innerHTML.length < 100) {
    document.getElementById('general_panel').innerHTML = '<p>沒有找到資源，請更換查詢條件或是關鍵字</p>';
    tinyMCE.DOM.doc.getElementById(tinyMCEPopup.id).style.top = "70px";
}

var w = document.body.clientWidth+10;
var h = document.body.clientHeight+10;

tinyMCEPopup.params.mce_height = h;
tinyMCEPopup.params.mce_width = w;
tinyMCEPopup.resizeToInnerSize();

var vpw = tinyMCE.DOM.getViewPort().w; 
var vph = tinyMCE.DOM.getViewPort().h; 

var top = vph > h ? (vph-h)/2 : 0;
var left = vpw > w ? (vpw-w)/2 : 0; 

// recenter.
var popup = tinyMCE.DOM.doc.getElementById(tinyMCEPopup.id); 
popup.style.top = top+"px";
popup.style.left = left+"px"; 
</script>
<?=$OUTPUT->footer()?>